@@ -469,21 +469,70 @@ class SaltCall(object):
                 default='',
                 help='Specify an additional directories to pull modules from,'\
                     + ' multiple directories can be delimited by commas')
+        parser.add_option('-c',
+                '--config',
+                dest='config',
+                default='/etc/salt/minion',
+                help='Pass in an alternative configuration file')
         parser.add_option('-d',
                 '--doc',
                 dest='doc',
                 default=False,
                 action='store_true',
-                help="Return the documentation for the specified module of'\
-                    + ' for all modules if none are specified")
+                help='Return the documentation for the specified module of'\
+                    + ' for all modules if none are specified')
+        parser.add_option('-l',
+                '--log-level',
+                default='info',
+                dest='log_level',
+                help='Set the output level for salt-call')
+        parser.add_option('--raw-out',
+                default=False,
+                action='store_true',
+                dest='raw_out',
+                help='Print the output from the salt command in raw python'\
+                   + ' form, this is suitable for re-reading the output into'\
+                   + ' an executing python script with eval.')
+        parser.add_option('--text-out',
+                default=False,
+                action='store_true',
+                dest='txt_out',
+                help='Print the output from the salt command in the same form '\
+                   + 'the shell would.')
+        parser.add_option('--yaml-out',
+                default=False,
+                action='store_true',
+                dest='yaml_out',
+                help='Print the output from the salt command in yaml.')
+        if JSON:
+            parser.add_option('--json-out',
+                    default=False,
+                    action='store_true',
+                    dest='json_out',
+                    help='Print the output from the salt command in json.')
+        parser.add_option('--no-color',
+                default=False,
+                dest='no_color',
+                action='store_true',
+                help='Disable all colored output')
 
         options, args = parser.parse_args()
 
         opts = {}
 
-        opts['grains'] = options.grains
+        opts['grains_run'] = options.grains
         opts['module_dirs'] = options.module_dirs.split(',')
         opts['doc'] = options.doc
+        opts['raw_out'] = options.raw_out
+        opts['txt_out'] = options.txt_out
+        opts['yaml_out'] = options.yaml_out
+        opts['color'] = not options.no_color
+        if JSON:
+            opts['json_out'] = options.json_out
+        else:
+            opts['json_out'] = False
+        opts.update(salt.config.minion_config(options.config))
+        opts['log_level'] = options.log_level
         if len(args) >= 1:
             opts['fun'] = args[0]
             opts['arg'] = args[1:]
@@ -497,6 +546,11 @@ class SaltCall(object):
         '''
         Execute the salt call!
         '''
+        import salt.log
+        salt.log.setup_console_logger(
+            self.opts['log_level']
+        )
+        import logging
         caller = salt.cli.caller.Caller(self.opts)
         caller.run()
 
