@@ -67,7 +67,7 @@ def minion_config(path):
             'log_level': 'warning',
             'log_granular_levels': {},
             'test': False,
-            'cython_enable': True,
+            'cython_enable': False,
             }
 
     load_config(opts, path, 'SALT_MINION_CONFIG')
@@ -114,7 +114,7 @@ def master_config(path):
             'open_mode': False,
             'auto_accept': False,
             'renderer': 'yaml_jinja',
-            'state_top': 'top.yml',
+            'state_top': 'top.sls',
             'order_masters': False,
             'log_file': '/var/log/salt/master',
             'log_level': 'warning',
