@@ -10,6 +10,7 @@ data
 import os
 import grp
 import pwd
+import hashlib
 
 import salt.utils.find
 
@@ -147,9 +148,9 @@ def chown(path, user, group):
     uid = user_to_uid(user)
     gid = group_to_gid(group)
     err = ''
-    if not uid:
+    if uid == '':
         err += 'User does not exist\n'
-    if not gid:
+    if gid == '':
         err += 'Group does not exist\n'
     if not os.path.isfile(path):
         err += 'File not found'
@@ -166,7 +167,7 @@ def chgrp(path, group):
     '''
     gid = group_to_gid(group)
     err = ''
-    if not gid:
+    if gid == '':
         err += 'Group does not exist\n'
     if not os.path.isfile(path):
         err += 'File not found'
@@ -186,9 +187,15 @@ def get_sum(path, form='md5'):
     if not os.path.isfile(path):
         return 'File not found'
     try:
-        return getattr(hashlib, form)(open(path, 'rb')).hexdigest()
-    except:
+        return getattr(hashlib, form)(open(path, 'rb').read()).hexdigest()
+    except (IOError, OSError), e:
+        return 'File Error: %s' % (str(e))
+    except AttributeError, e:
         return 'Hash ' + form + ' not supported'
+    except NameError, e:
+        return 'Hashlib unavailable - please fix your python install'
+    except Exception, e:
+        return str(e)
 
 def find(path, *opts):
     '''
@@ -281,7 +288,7 @@ def find(path, *opts):
     try:
         f = salt.utils.find.Finder(opts_dict)
     except ValueError, ex:
-        return 'error: {}'.format(ex)
+        return 'error: {0}'.format(ex)
 
     ret = [p for p in f.find(path)]
     ret.sort()
