@@ -11,7 +11,6 @@ The data sent to the state calls is as follows:
       }
 '''
 # Import python modules
-import sys
 import os
 import copy
 import inspect
@@ -89,7 +88,15 @@ class State(object):
             return errors
         full = data['state'] + '.' + data['fun']
         if not self.states.has_key(full):
-            errors.append('Specified state ' + full + ' is unavailable.')
+            if data.has_key('__sls__'):
+                errors.append(
+                    'State {0} found in sls {1} is unavailable'.format(
+                        full,
+                        data['__sls__']
+                        )
+                    )
+            else:
+                errors.append('Specified state ' + full + ' is unavailable.')
         else:
             aspec = inspect.getargspec(self.states[full])
             arglen = 0
@@ -104,6 +111,22 @@ class State(object):
                                 + ' for state ' + full)
         return errors
 
+    def verify_high(self, high):
+        '''
+        Verify that the high data is viable and follows the data structure
+        '''
+        errors = []
+        if not isinstance(high, dict):
+            errors.append('High data is not a dictonary and is invalid')
+        for name, body in high.items():
+            if not isinstance(body, dict):
+                err = 'The type {0} is not formated as a dictonary'.format(name)
+                errors.append(err)
+                continue
+            for state, run in body.items():
+                pass
+        return errors
+
     def verify_chunks(self, chunks):
         '''
         Verify the chunks in a list of low data structures
@@ -160,8 +183,12 @@ class State(object):
         chunks = []
         for name, body in high.items():
             for state, run in body.items():
+                if state.startswith('__'):
+                    continue
                 chunk = {'state': state,
                          'name': name}
+                if body.has_key('__sls__'):
+                    chunk['__sls__'] = body['__sls__']
                 funcs = set()
                 names = set()
                 for arg in run:
@@ -195,6 +222,8 @@ class State(object):
         Take the path to a template and return the high data structure derived
         from the template.
         '''
+        if not isinstance(template, str):
+            return {}
         if not os.path.isfile(template):
             return {}
         return self.rend[self.opts['renderer']](template)
@@ -340,8 +369,11 @@ class State(object):
         '''
         err = []
         rets = []
+        errors = self.verify_high(high)
+        if errors:
+            return errors
         chunks = self.compile_high_data(high)
-        errors = self.verify_chunks(chunks)
+        errors += self.verify_chunks(chunks)
         if errors:
             return errors
         return self.call_chunks(chunks)
@@ -416,7 +448,7 @@ class HighState(object):
         matches = {}
         for env, body in top.items():
             for match, data in body.items():
-                if self.matcher.confirm_top(data):
+                if self.matcher.confirm_top(match, data):
                     if not matches.has_key(env):
                         matches[env] = []
                     for item in data:
@@ -440,17 +472,34 @@ class HighState(object):
         '''
         Render a state file and retrive all of the include states
         '''
+        errors = []
         fn_ = self.client.get_state(sls, env)
-        state = self.state.compile_template(fn_)
+        state = None
+        try:
+            state = self.state.compile_template(fn_)
+        except Exception as exc:
+            errors.append('Rendering SLS {0} failed, render error:\n{1}'.format(sls, exc))
         mods.add(sls)
+        nstate = None
         if state:
-            if state.has_key('include'):
-                for sub_sls in state.pop('include'):
-                    if not list(mods).count(sub_sls):
-                        nstate, mods = self.render_state(sub_sls, env, mods)
-                    if nstate:
-                        state.update(nstate)
-        return state, mods
+            if not isinstance(state, dict):
+                errors.append('SLS {0} does not render to a dictonary'.format(sls))
+            else:
+                if state.has_key('include'):
+                    for sub_sls in state.pop('include'):
+                        if not list(mods).count(sub_sls):
+                            nstate, mods, err = self.render_state(sub_sls, env, mods)
+                        if nstate:
+                            state.update(nstate)
+                        if err:
+                            errors += err
+                for name in state:
+                    if not isinstance(state[name], dict):
+                        errors.append('Name {0} in sls {1} is not a dictonary'.format(name, sls))
+                        continue
+                    if not state[name].has_key('__sls__'):
+                        state[name]['__sls__'] = sls
+        return state, mods, errors
 
     def render_highstate(self, matches):
         '''
@@ -458,13 +507,16 @@ class HighState(object):
         data structure. 
         '''
         highstate = {}
+        errors = []
         for env, states in matches.items():
             mods = set()
             for sls in states:
-                state, mods = self.render_state(sls, env, mods)
+                state, mods, err = self.render_state(sls, env, mods)
                 if state:
                     highstate.update(state)
-        return highstate
+                if err:
+                    errors += err
+        return highstate, errors
 
     def call_highstate(self):
         '''
@@ -472,5 +524,7 @@ class HighState(object):
         '''
         top = self.get_top()
         matches = self.top_matches(top)
-        high = self.render_highstate(matches)
+        high, errors = self.render_highstate(matches)
+        if errors:
+            return errors
         return self.state.call_high(high)
