@@ -11,13 +11,13 @@ def present(name, ip):
            'result': False,
            'comment': ''}
     if __salt__['hosts.has_pair'](ip, name):
-        ret['changes'] = 'Already Present'
         ret['result'] = True
+        ret['comment'] = 'Host {0} already present'.format(name)
         return ret
     if __salt__['hosts.add_host'](ip, name):
         ret['changes'] = {'host': name}
         ret['result'] = True
-        ret['comment'] = 'Added host ' + name
+        ret['comment'] = 'Added host {0}'.format(name)
         return ret
     else:
         ret['result'] = False
@@ -33,13 +33,13 @@ def absent(name, ip):
            'result': False,
            'comment': ''}
     if not __salt__['hosts.has_pair'](ip, name):
-        ret['changes'] = 'Already Absent'
         ret['result'] = True
+        ret['comment'] = 'Host {0} already absent'.format(name)
         return ret
     if __salt__['hosts.rm_host'](ip, name):
         ret['changes'] = {'host': name}
         ret['result'] = True
-        ret['comment'] = 'Removed host ' + name
+        ret['comment'] = 'Removed host {0}'.format(name)
         return ret
     else:
         ret['result'] = False
